#ifndef JOB_CALLMUSICEXTRAS_H
#define JOB_CALLMUSICEXTRAS_H

#include "prokyon.h"
#include "jobbase.h"
#include "musicextraswrapper.h"

class Job_CallMusicextras : public JobBase {

public:
    Job_CallMusicextras( TRACK _track, bool _refresh );

    int type() {
        return JOB_CALL_MUSICEXTRAS;
    }

    static void JobSleep ( unsigned long msecs ) {
        msleep( msecs);
    }
    void run();
    void safeTerminate() {
        terminated=true;
        if (mw)
            mw->safeTerminate();
    }   // set safe termination flag

    ~Job_CallMusicextras();

private:
    TRACK track;
    MusicextrasWrapper *mw;
    bool refresh;
    bool terminated;
    EXTRADATA *data;
    int error;
    int countCovers;
    int countLyrics;
    int countImages;

};

#endif
